define(
//begin v1.x content
({
	insertTableTitle: "Inserir Tabela",
	modifyTableTitle: "Modificar Tabela",
	rows: "Linhas:",
	columns: "Colunas:",
	align: "Alinhar:",
	cellPadding: "Preenchimento de Célula:",
	cellSpacing: "Espaçamento de Célula:",
	tableWidth: "Largura da Tabela:",
	backgroundColor: "Cor do Plano de Fundo:",
	borderColor: "Cor da Borda:",
	borderThickness: "Grossura da Borda",
	percent: "percentual",
	pixels: "pixels",
	"default": "default",
	left: "esquerda",
	center: "centro",
	right: "direita",
	buttonSet: "Configurar", // translated elsewhere?
	buttonInsert: "Inserir",
	buttonCancel: "Cancelar",

	selectTableLabel: "Selecionar Tabela",
	insertTableRowBeforeLabel: "Incluir Linha Antes",
	insertTableRowAfterLabel: "Incluir Linha Depois",
	insertTableColumnBeforeLabel: "Incluir Coluna Antes",
	insertTableColumnAfterLabel: "Incluir Coluna Depois",
	deleteTableRowLabel: "Excluir Linha",
	deleteTableColumnLabel: "Excluir Coluna"
})
	
//end v1.x content
);
